<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 06/10/2005 *
 * ===================                          Last change: 05/18/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-sponsor_reg.php                             *
 * -------------------------------------------------------------------- *
 * Short description : Sponsor's registration form                      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Anmeldeformular fuer Sponsoren                   *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2016 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} // END - if

// Add description as navigation point
addYouAreHereLink('guest', __FILE__);

if ((!isExtensionActive('sponsor'))) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=sponsor%}');
	return;
} // END - if

// Create array for form errors (= missing data)
$formErrors = array();

if (isFormSent()) {
	//
	// Check submitted form data
	//
	// 1. Salutation / Surname / family name
	if (!isPostRequestElementSet('gender')) {
		// Surname is empty
		array_push($formErrors, '{--SPONSOR_NO_GENDER_SELECTED--}');
	} // END - if

	if (!isPostRequestElementSet('surname')) {
		// Surname is empty
		array_push($formErrors, '{--SPONSOR_SURNAME_EMPTY--}');
	} // END - if

	if (!isPostRequestElementSet('family')) {
		// Surname is empty
		array_push($formErrors, '{--SPONSOR_FAMILY_EMPTY--}');
	} // END - if

	// 2. Company name
	// 012                          3         32    23                         4           43    3                         4          4321    12                         3         32    2                          3           3210
	if (((!isPostRequestElementSet('company')) && ((isPostRequestElementSet('tax_ident')) || (isPostRequestElementSet('position')))) || ((isPostRequestElementSet('company')) && (!isPostRequestElementSet('tax_ident')))) {
		if (!isPostRequestElementSet('company')) {
			// Company name is empty
			array_push($formErrors, '{--SPONSOR_COMPANY_EMPTY--}');
		} elseif (!isPostRequestElementSet('tax_ident')) {
			// Tax ident number name is empty
			array_push($formErrors, '{--SPONSOR_TAX_IDENT_EMPTY--}');
		}

		if (!isPostRequestElementSet('position')) {
			// Not fatal but not nice: position in company is empty
			array_push($formErrors, '{--SPONSOR_POSITION_EMPTY--}');
		} // END - if
	} // END - if

	// 3. Street and number
	if (!isPostRequestElementSet('street_nr1')) {
		// Street name and house number are empty
		array_push($formErrors, '{--SPONSOR_STREET_NR1_EMPTY--}');
	} elseif ((isPostRequestElementSet('street_nr2')) && (!isPostRequestElementSet('street_nr1'))) {
		// 1st line for street is empty, but 2nd line not
		array_push($formErrors, '{--SPONSOR_STREET_NR1_EMPTY_2_NOT--}');
	}

	// 4. Country code
	if (!isPostRequestElementSet('country')) {
		// Country code is empty
		array_push($formErrors, '{--kSPONSOR_COUNTRY_EMPTY--}');
	} elseif (strlen(postRequestElement('country')) != 2) {
		// Country code is invalid
		array_push($formErrors, '{--SPONSOR_COUNTRY_IS_INVALID--}');
	}

	// 3. ZIP code
	if (!isPostRequestElementSet('zip')) {
		// ZIP code is empty
		array_push($formErrors, '{--SPONSOR_ZIP_EMPTY--}');
	} elseif (bigintval(postRequestElement('zip')) != postRequestElement('zip')) {
		// ZIP is invalid
		array_push($formErrors, '{--SPONSOR_ZIP_IS_INVALID--}');
		setPostRequestElement('zip', '');
	}

	// 4. City
	if (!isPostRequestElementSet('city')) {
		// City is empty
		array_push($formErrors, '{--SPONSOR_CITY_EMPTY--}');
	} // END - if

	// 5. Phone number
	if (!isPostRequestElementSet('phone')) {
		// City is empty
		array_push($formErrors, '{--SPONSOR_PHONE_EMPTY--}');
	} // END - if

	// 6. Homepage URL
	if (!isPostRequestElementSet('url')) {
		// Homepage URL is empty
		array_push($formErrors, '{--SPONSOR_URL_EMPTY--}');
	} elseif (!isUrlValid(postRequestElement('url'))) {
		// Homepage URL is invalid
		array_push($formErrors, '{--SPONSOR_URL_IS_INVALID--}');
		setPostRequestElement('url', '');
	}

	// 7. Light validation of email address
	if ((!isPostRequestElementSet('email')) || (postRequestElement('email') == '@')) {
		// Email is invalid/empty
		array_push($formErrors, '{--SPONSOR_EMAIL_IS_INVALID--}');
	} elseif (isSponsorRegisteredWithEmail(postRequestElement('email'))) {
		// Email already found in database!
		array_push($formErrors, '{--SPONSOR_EMAIL_IS_ALREADY_REGISTERED--}');
		setPostRequestElement('email', '');
	}

	// 8. Pay type selected?
	if (!isPostRequestElementSet('pay_type')) {
		// Not pay type selected
		array_push($formErrors, '{--SPONSOR_NO_PAYTYPE_SELECTED--}');
	} // END - if

	// 9. Interval of mails
	if (!isPostRequestElementSet('warning_interval')) {
		// No warning interval selected
		array_push($formErrors, '{--SPONSOR_NO_WARNING_INTERVAL_SELECTED--}');
	} // END - if

	// 10. Mail notifications disabled/enabled
	if (!isPostRequestElementSet('receive_warnings')) {
		// Option not selected!
		array_push($formErrors, '{--SPONSOR_NO_RECEIVE_WARNINGS_SELECTED--}');
	} // END - if

	// Did he enter his password twice?
	if (((!isPostRequestElementSet('password1')) || (!isPostRequestElementSet('password2'))) || ((postRequestElement('password1') != postRequestElement('password2')) && (isPostRequestElementSet('password1')) && (isPostRequestElementSet('password2')))) {
		if ((postRequestElement('password1') != postRequestElement('password2')) && (isPostRequestElementSet('password1')) && (isPostRequestElementSet('password2'))) {
			// Passwords missmatch
			array_push($formErrors, '{--SPONSOR_PASSWORDS_MISMATCH--}');
		} else {
			if (!isPostRequestElementSet('password1')) {
				// Password 1 is empty
				array_push($formErrors, '{--SPONSOR_PASSWORD1_EMPTY--}');
			}

			if (!isPostRequestElementSet('password2')) {
				// Password 2 is empty
				array_push($formErrors, '{--SPONSOR_PASSWORD2_EMPTY--}');
			}
		}
	} elseif (strlen(postRequestElement('password1')) < getMinPasswordLength()) {
		// Password is to short!
		array_push($formErrors, '{--SPONSOR_PASSWORD_TOO_SHORT--}');
	}

	// Check if he has accepted the terms&conditions
	if (!isPostRequestElementSet('terms')) {
		// Homepage URL is empty
		array_push($formErrors, '{--SPONSOR_TERMS_NOT_ACCEPTED--}');
	} // END - if

	// If there is something wrong/missing stop registration
	if (isFilledArray($formErrors)) unsetPostRequestElement('ok');
} // END - if

if ((isFormSent()) && (!isFilledArray($formErrors))) {
	// Generate message array
	$messageArray = array(
		'failed' => '{--SPONSOR_REGISTRATION_FAILED--}',
		'added'  => '{--SPONSOR_REGISTRATION_COMPLETED--}',
	);

	// Calulate points
	$result = sqlQueryEscaped('SELECT
	(`pay_rate` * `pay_min_count`) AS `points`,
	`pay_min_count`,
	`pay_currency`
FROM
	`{?_MYSQL_PREFIX?}_sponsor_paytypes`
WHERE
	`id`=%s
LIMIT 1',
		array(postRequestElement('pay_type')), __FILE__, __LINE__);
	list($points, $pay, $curr) = sqlFetchRow($result);

	// Free memory
	sqlFreeResult($result);

	// Add points to array
	postRequestElement('points_amount', $points);
	postRequestElement('points_used'  , '0.00000');
	postRequestElement('last_payment' , $pay);
	postRequestElement('last_currency', $curr);

	// Register sponsor but never ever update here!
	$message = doProcessSponsorFormRequest($messageArray);

	// Display message
	displayMessage($message);
} else {
	// Check for payment types
	$result = sqlQuery('SELECT
	`id`,
	`pay_name`,
	`pay_rate`,
	`pay_currency`,
	`pay_min_count`
FROM
	`{?_MYSQL_PREFIX?}_sponsor_paytypes`
ORDER BY
	`pay_name` ASC', __FILE__, __LINE__);

	if (!ifSqlHasZeroNumRows($result)) {
		// Load all types...
		$OUT = '';
		while ($content = sqlFetchArray($result)) {
			// Prepare content for output
			$content['res'] = translateComma($content['pay_rate'] * $content['pay_min_count']);

			// Load row template and switch color
			$OUT .= loadTemplate('guest_sponsor_payment_row', TRUE, $content);
		} // END - while

		// Remember the list in table
		$content['payment_list'] = loadTemplate('guest_sponsor_payment', TRUE, $OUT);

		// Init a lot array elements
		foreach (array('company','position','tax_ident','gender_m','gender_f','gender_c','surname','family','street_nr1','street_nr2','country','zip','city','phone','fax','cell','email','url','receive_warnings_y','receive_warnings_n','form_errors','refid') as $entry) {
			$content[$entry]   = '';
		} // END - foreach

		// Check for invalid entries
		if (isFilledArray($formErrors)) {
			// Some found... :-(
			foreach (array('company','position','tax_ident','surname','family','street_nr1','street_nr2','country','zip','city','phone','fax','cell','email','url') as $entry) {
				$content[$entry]    = postRequestElement($entry);
			} // END - foreach

			// Init receive selection
			$content['receive_warnings_y'] = '';
			$content['receive_warnings_n'] = '';

			// Check for receive_warnings
			$content['receive_warnings_' . strtolower(postRequestElement('receive_warnings'))] = ' selected="selected"';
			$OUT = '';

			// Errors found?
			if (isFilledArray($formErrors)) {
				$OUT = returnMessage('{--SPONSOR_REGISTER_SOMETHING_MISSING--}');
				$OUT .= '<ol>';
				foreach ($formErrors as $error) {
					$OUT .= '<li>' . $error . '</li>';
				} // END - foreach

				$OUT .= '</ol>';
			} // END - if

			$content['form_errors'] = $OUT;

			// @TODO Maybe a default referral id?
			$content['refid'] = NULL;

			// Is the referral id valid?
			if ((isPostRequestElementSet('refid')) && (isValidId(postRequestElement('refid')))) {
				// Transfer referral id
				$content['refid'] = bigintval(postRequestElement('refid'));
			} // END - if
		} // END - if

		// Display registration form
		loadTemplate('guest_sponsor_reg', FALSE, $content);
	} else {
		// Nothing added so far
		displayMessage('{--SPONSOR_PAYMENT_LIST_EMPTY--}');
	}

	// Free memory
	sqlFreeResult($result);
}

// [EOF]
?>
