<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 06/22/2013 *
 * ===================                          Last change: 06/22/2013 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-transactions.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Confirm transactions of other members            *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Transaktionen anderer Mitglieder bestaetigen     *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2016 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} elseif (!isMember()) {
	redirectToIndexMemberOnlyModule();
}

// Add description as navigation point
addYouAreHereLink('member', __FILE__);

// Continue only if the proper extension is active (admins can always continue)
if ((!isExtensionActive('transaction')) && (!isAdmin())) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=transaction%}');
	return;
} elseif ((isFormSent()) &&  (ifPostContainsSelections('transaction_id'))) {
	// Try to confirm transactions
	if (doTryConfirmTransactions($_POST)) {
		// All fine
		displayMessage('Best&auml;tigung der CAPTCHA(s) abgeschlossen. Vielen Dank.');
	} else {
		// None confirmed
		displayMessage('Es konnten keine CAPTCHA(s) best&auml;tigt werden. Vermutlich weil Sie diese bereits best&auml;tigt haben.');
	}
}

// Load X most oldest transactions this user is not sender and not receiver
$result = sqlQueryEscaped("SELECT
	`transaction_id`
FROM
	`{?_MYSQL_PREFIX?}_transaction_log`
WHERE
	`transaction_sender` != %s AND
	`transaction_sender` IS NOT NULL AND
	`transaction_receiver` != %s AND
	`transaction_receiver` IS NOT NULL AND
	`transaction_hash` != 'INVALID' AND
	`transaction_confirmed`='N' AND
	`transaction_captcha_failed`='N' AND
	`transaction_fee_collected`='N' AND
	`transaction_level` IS NULL AND
	`transaction_captcha` IS NOT NULL
ORDER BY
	`transaction_hash` ASC
LIMIT {?transaction_max_captcha?}",
	array(
		getCurrentUserId(),
		getCurrentUserId()
	), __FILE__, __LINE__
);

// Init variables
$OUT = '';

// Are there entries?
if (sqlNumRows($result) > 0) {
	// Then load all
	$row = '';
	while (list($id) = sqlFetchRow($result)) {
		// Load "row" template
		$row .= loadTemplate('member_transactions_row', TRUE, $id);
	} // END - while

	// Load form template
	$OUT .= loadTemplate('member_transactions_form', TRUE, $row);
} else {
	// Display message
	$OUT .= returnMessage('Es sind noch keine Transaktionen zum Best&auml;tigen vorhanden. Neu zu best&auml;tigende Transaktionen gibt es durch den &quot;Stundenreset&quot;, der ungef&auml;hr zur vollen Stunde l&auml;uft.');
}

// Free result
sqlFreeResult($result);

// Get summarizations
$result = sqlQuery("SELECT
	SUM(`transaction_fee_sender`) AS `total_sender`,
	SUM(`transaction_fee_receiver`) AS `total_receiver`
FROM
	`{?_MYSQL_PREFIX?}_transaction_log`
WHERE
	`transaction_fee_collected`='N' AND
	`transaction_confirmed`='N' AND
	`transaction_captcha_failed`='N'
LIMIT 1", __FILE__, __LINE__);

// Get values
list($totalSenderN, $totalReceiverN) = sqlFetchRow($result);

// Free result
sqlFreeResult($result);

// Get summarizations
$result = sqlQuery("SELECT
	SUM(`transaction_fee_sender`) AS `total_sender`,
	SUM(`transaction_fee_receiver`) AS `total_receiver`
FROM
	`{?_MYSQL_PREFIX?}_transaction_log`
WHERE
	`transaction_fee_collected`='Y'
LIMIT 1", __FILE__, __LINE__);

// Get values
list($totalSenderY, $totalReceiverY) = sqlFetchRow($result);

// Free result
sqlFreeResult($result);

// Get summarizations
$result = sqlQuery("SELECT
	COUNT(`transaction_id`) AS `cnt`,
	(SUM(`transaction_fee_sender`) + SUM(`transaction_fee_receiver`)) AS `total_confirmed`
FROM
	`{?_MYSQL_PREFIX?}_transaction_log`
WHERE
	`transaction_confirmed`='Y'
LIMIT 1", __FILE__, __LINE__);

// Get values
list($confirmedCount, $totalConfirmed) = sqlFetchRow($result);

// Free result
sqlFreeResult($result);

// Prepare content
$content = array(
	'captcha_content'                => $OUT,
	'transaction_confirmed'          => translateComma(getUserData('transaction_confirmed'), TRUE),
	'total_sender_uncollected'       => $totalSenderN,
	'total_receiver_uncollected'     => $totalReceiverN,
	'total_sender_collected'         => $totalSenderY,
	'total_receiver_collected'       => $totalReceiverY,
	'total_confirmed_count'          => translateComma($confirmedCount, TRUE),
	'total_confirmed'                => $totalConfirmed,
);

// Load main template
loadTemplate('member_transactions', FALSE, $content);

// [EOF]
?>
