<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 09/05/2008 *
 * ===================                          Last change: 09/05/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : surfbar.php                                      *
 * -------------------------------------------------------------------- *
 * Short description : The surfbar itself                               *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Die Surfbar selbst                               *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2016 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Load security stuff here
require('inc/libs/security_functions.php');

// Init start time
$GLOBALS['__start_time'] = microtime(TRUE);

// Set module output mode
$GLOBALS['__module']      = 'surfbar';
$GLOBALS['__output_mode'] = '0';
$GLOBALS['__header_sent'] = 3;

// Load the required file(s)
require('inc/config-global.php');

// Set content type
setContentType('text/html');

// Is a frame active?
if (!isFullPage()) {
	// Then we need to set header_sent to 0
	$GLOBALS['__header_sent'] = '0';
} // END - if

// Only logged in users may use this surfbar!
redirectOnUninstalledExtension('surfbar');

// No member?
if (!isMember()) {
	// Should we display login window or redirect to main page?
	if ((isSurfbarGuestLoginFormEnabled()) && (isExtensionActive('user'))) {
		// Is the form sent?
		if ((isFormSent('login')) && (isPostRequestElementSet('id')) && (isPostRequestElementSet('password'))) {
			// Do the login procedure
			$url = doUserLogin(postRequestElement('id'), postRequestElement('password'), basename(__FILE__), basename(__FILE__) . '?code=');

			// And redirect to the URL
			redirectToUrl($url);
		} else {
			// Load header
			loadPageHeader();

			// Is there a 'code' provided?
			if (isGetRequestElementSet('code')) {
				// Then generate an error message
				displayMessage(getMessageFromErrorCode(getRequestElement('code')));
			} // END - if

			// Display login form
			loadTemplate('surfbar_login_form');

			// Allow footer here
			$GLOBALS['__header_sent'] = 2;

			// Load footer
			loadPageFooter();
		}
	} else {
		// Redirect
		redirectToUrl('modules.php?module=index');
	}
} // END - if

// Initialize the surfbar
initSurfbar();

// Handle tasks on self-maintenance
doSurfbarSelfMaintenance();

// Is there a check value?
if ((isSurfbarReloadFull()) || ((!isFullPage()) && (in_array(getRequestElement('frame'), array('stop', 'stop2', 'stats', 'textlinks'))))) {
	// Reload-lock is full, surfbar stopped so...
	// Load header
	loadPageHeader();

	// Load template
	if (((!isFullPage()) && (getRequestElement('frame') == 'stop2')) || (isFullPage())) {
		// Load template for "start" page
		loadTemplate('surfbar_frame_start');

		// Load banner
		loadTemplate('surfbar_start_banner');

		// This makes the footer appear again
		unsetGetRequestElement('frame');
	} elseif ((!isFullPage()) && (getRequestElement('frame') == 'stats')) {
		// Prepare content
		$content = array(
			'points' => getTotalPoints(getMemberId()),
			'reload' => (getSurfbarStatsReload() * 1000)
		);

		// Load template for "stats" page
		loadTemplate('surfbar_frame_stats', FALSE, $content);
	} elseif ((!isFullPage()) && (getRequestElement('frame') == 'textlinks')) {
		// Prepare content
		$content = array(
			'reload' => (getSurfbarStatsReload() * 1000)
		);

		// Load template for "stats" page
		loadTemplate('surfbar_frame_textlinks', FALSE, $content);
	} else {
		// Prepare content
		$content = array(
			'start'     => str_repeat('X', strlen(getSurfbarRestartTime())),
			'autostart' => (isSurfbarAutoStartEnabled()) ? 'true' : 'false'
		);

		// Load template for stopped surfbar
		loadTemplate('surfbar_stopped', FALSE, $content);
	}
} elseif ((isGetRequestElementSet('check')) && (isGetRequestElementSet('id')) && (isGetRequestElementSet('salt'))) {
	// Dummy next id get
	determineSurfbarNextId(getRequestElement('id'));

	// Check reload lock and validation code
	if ((!ifSurfbarReloadLock(getRequestElement('id'))) && (isSurfbarValidationCodeValid(getRequestElement('id'), getRequestElement('check'), getRequestElement('salt')))) {
		// Lock the URL (id) down
		addSurfbarReloadLockById(getRequestElement('id'));

		// Code is valid so pay points here
		doSurfbarPayPoints();

		// Check if reload is full
		if (isSurfbarReloadFull()) {
			// Then load waiting page
			redirectToSurfbarStopPage();
		} // END - if

		// Load header to avoid a bug
		loadPageHeader();
	} else {
		// Reload to stop frame!
		redirectToSurfbarStopPage();
	}

	// All done, so fix notice for loadTemplateFooter()
	$GLOBALS['__footer_sent'] = 1;
} else {
	// Prepare content
	$content = '';

	// Frame "top" set?
	if ((!isFullPage()) && (getRequestElement('frame') == 'top')) {
		// Determine next id
		$nextId = determineSurfbarNextId();
		//* DEBUG: */ exit('nextId='.$nextId);

		// Is there a valid id?
		if (isValidId($nextId)) {
			// Then prepare other content
			$content = array(
				'url_id' => $nextId,
				'xxx'    => str_repeat('X', strlen(getSurfbarWaitingTime($nextId))),
			);

			// Update salt (double-call lock!) and statistics
			updateSurfbarSaltStatistics();
		} else {
			// Load new URL
			redirectToSurfbarStopPage('stop');
		}
	} elseif ((!isFullPage()) && (getRequestElement('frame') == 'start')) {
		// Starter frame found so let the footer display
		unsetGetRequestElement('frame');
	}

	// Load header
	loadPageHeader();

	// Determine template name
	$templateName = determineSurfbarTemplateName();

	// Load that template
	//* DEBUG: */ exit('templateName=' . $templateName . '<br /><strong>content</strong>=<pre>' . print_r($content, TRUE) . '</pre>');
	loadTemplate($templateName, FALSE, $content);
}

// Load footer
$GLOBALS['__footer_sent'] = 3;
loadPageFooter();

// [EOF]
?>
